@@ -1,5 +1,6 @@
 import express from 'express';
 import asyncHandler from 'express-async-handler';
+import * as z from 'zod';
 
 import { Op } from 'sequelize';
 import { log } from '@tamanu/shared/services/logging';
@@ -339,6 +340,22 @@ export const buildSyncRoutes = ctx => {
     }),
   );
 
+  const postErrorBodySchema = z.object({
+    error: z.string(),
+  });
+  // mark session as errored, so server will record the error and cancel the sync
+  syncRoutes.post(
+    '/:sessionId/error',
+    asyncHandler(async (req, res) => {
+      const { params } = req;
+      const { sessionId } = params;
+      const { error } = await postErrorBodySchema.parseAsync(req.body);
+
+      await syncManager.endSession(sessionId, error);
+      res.json({});
+    }),
+  );
+
   // end session
   syncRoutes.delete(
     '/:sessionId',
