@@ -41,6 +41,8 @@ import {
   DRUG_UNIT_LABELS,
   DRUG_UNIT_SHORT_LABELS,
   REPEATS_LABELS,
+  DRUG_STOCK_STATUS_LABELS,
+  PHARMACY_PRESCRIPTION_TYPE_LABELS,
 } from './medications.js';
 import { PLACE_OF_DEATHS, MANNER_OF_DEATHS } from './deaths';
 import { LOCATION_AVAILABILITY_STATUS_LABELS } from './locations';
@@ -51,10 +53,7 @@ import {
   REPEAT_FREQUENCY_UNIT_LABELS,
   REPEAT_FREQUENCY_UNIT_PLURAL_LABELS,
 } from './appointments';
-import {
-  DEPRECATED_PRCC_LABELS,
-  PROGRAM_REGISTRATION_STATUS_LABELS,
-} from './programRegistry';
+import { DEPRECATED_PRCC_LABELS, PROGRAM_REGISTRATION_STATUS_LABELS } from './programRegistry';
 
 type EnumKeys = keyof typeof registeredEnums;
 type EnumValues = (typeof registeredEnums)[EnumKeys];
@@ -113,6 +112,8 @@ export const registeredEnums = {
   TITLE_LABELS,
   VACCINE_CATEGORY_LABELS,
   VACCINE_STATUS_LABELS,
+  DRUG_STOCK_STATUS_LABELS,
+  PHARMACY_PRESCRIPTION_TYPE_LABELS,
 };
 
 /**
@@ -169,6 +170,8 @@ export const translationPrefixes: Record<EnumKeys, string> = {
   TITLE_LABELS: 'patient.property.title',
   VACCINE_CATEGORY_LABELS: 'vaccine.property.category',
   VACCINE_STATUS_LABELS: 'vaccine.property.status',
+  DRUG_STOCK_STATUS_LABELS: 'medication.property.drugStockStatus',
+  PHARMACY_PRESCRIPTION_TYPE_LABELS: 'medication.property.pharmacyPrescriptionType',
 };
 
 export const enumRegistry = new Set(Object.values(registeredEnums));
